@@ -47,6 +47,23 @@ impl crate::WriteTo for Tag {
         Ok(())
     }
 
+    fn size(&self) -> usize {
+        b"object".len() + 1 /* space */ + self.target.kind().len_in_hex() + 1 /* nl */
+            + b"type".len() + 1 /* space */ + self.target_kind.as_bytes().len() + 1 /* nl */
+            + b"tag".len() + 1 /* space */ + self.name.len() + 1 /* nl */
+            + self
+                .tagger
+                .as_ref()
+                .map(|t| b"tagger".len() + 1 /* space */ + t.size() + 1 /* nl */)
+                .unwrap_or(0)
+            + if self.message.is_empty() {
+                0
+            } else {
+                1 /* nl */ + self.message.len()
+            }
+            + self.pgp_signature.as_ref().map(|m| 1 /* nl */ + m.len() ).unwrap_or(0)
+    }
+
     fn kind(&self) -> Kind {
         Kind::Tag
     }
@@ -72,6 +89,23 @@ impl<'a> crate::WriteTo for TagRef<'a> {
         Ok(())
     }
 
+    fn size(&self) -> usize {
+        b"object".len() + 1 /* space */ + self.target().kind().len_in_hex() + 1 /* nl */
+            + b"type".len() + 1 /* space */ + self.target_kind.as_bytes().len() + 1 /* nl */
+            + b"tag".len() + 1 /* space */ + self.name.len() + 1 /* nl */
+            + self
+                .tagger
+                .as_ref()
+                .map(|t| b"tagger".len() + 1 /* space */ + t.size() + 1 /* nl */)
+                .unwrap_or(0)
+            + if self.message.is_empty() {
+                0
+            } else {
+                1 /* nl */ + self.message.len()
+            }
+            + self.pgp_signature.as_ref().map(|m| 1 /* nl */ + m.len()).unwrap_or(0)
+    }
+
     fn kind(&self) -> Kind {
         Kind::Tag
     }
